@@ -5,7 +5,9 @@
 #
 
 from scoutbot.loc.transforms import annotations  # NOQA
+from scoutbot.loc.transforms import box  # NOQA
 from scoutbot.loc.transforms import detections  # NOQA
+from scoutbot.loc.transforms import util  # NOQA
 from scoutbot.loc.transforms._postprocess import (  # NOQA
     GetBoundingBoxes,
     NonMaxSupression,
@@ -13,4 +15,3 @@ from scoutbot.loc.transforms._postprocess import (  # NOQA
     TensorToBrambox,
 )
 from scoutbot.loc.transforms._preprocess import Letterbox  # NOQA
-from scoutbot.loc.transforms.util import Compose  # NOQA
